@@ -14,25 +14,36 @@ OutputTimer *ot;
 
 OutputTimer::OutputTimer(QWidget *parent)
 	: QDialog(parent),
-	ui(new Ui_OutputTimer)
+	  ui(new Ui_OutputTimer)
 {
 	ui->setupUi(this);
 
-	QObject::connect(ui->outputTimerStream, SIGNAL(clicked()), this,
-		SLOT(StreamingTimerButton()));
-	QObject::connect(ui->outputTimerRecord, SIGNAL(clicked()), this,
-		SLOT(RecordingTimerButton()));
+	setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
+
+	QObject::connect(ui->outputTimerStream, &QPushButton::clicked, this,
+			 &OutputTimer::StreamingTimerButton);
+	QObject::connect(ui->outputTimerRecord, &QPushButton::clicked, this,
+			 &OutputTimer::RecordingTimerButton);
 	QObject::connect(ui->buttonBox->button(QDialogButtonBox::Close),
-		SIGNAL(clicked()), this, SLOT(hide()));
+			 &QPushButton::clicked, this, &OutputTimer::hide);
 
 	streamingTimer = new QTimer(this);
 	streamingTimerDisplay = new QTimer(this);
 
 	recordingTimer = new QTimer(this);
 	recordingTimerDisplay = new QTimer(this);
+
+	QObject::connect(streamingTimer, &QTimer::timeout, this,
+			 &OutputTimer::EventStopStreaming);
+	QObject::connect(streamingTimerDisplay, &QTimer::timeout, this,
+			 &OutputTimer::UpdateStreamTimerDisplay);
+	QObject::connect(recordingTimer, &QTimer::timeout, this,
+			 &OutputTimer::EventStopRecording);
+	QObject::connect(recordingTimerDisplay, &QTimer::timeout, this,
+			 &OutputTimer::UpdateRecordTimerDisplay);
 }
 
-void OutputTimer::closeEvent(QCloseEvent*)
+void OutputTimer::closeEvent(QCloseEvent *)
 {
 	obs_frontend_save();
 }
@@ -76,9 +87,7 @@ void OutputTimer::StreamTimerStart()
 	int minutes = ui->streamingTimerMinutes->value();
 	int seconds = ui->streamingTimerSeconds->value();
 
-	int total = (((hours * 3600) +
-		(minutes * 60)) +
-		seconds) * 1000;
+	int total = (((hours * 3600) + (minutes * 60)) + seconds) * 1000;
 
 	if (total == 0)
 		total = 1000;
@@ -86,17 +95,13 @@ void OutputTimer::StreamTimerStart()
 	streamingTimer->setInterval(total);
 	streamingTimer->setSingleShot(true);
 
-	QObject::connect(streamingTimer, SIGNAL(timeout()),
-		SLOT(EventStopStreaming()));
-
-	QObject::connect(streamingTimerDisplay, SIGNAL(timeout()), this,
-		SLOT(UpdateStreamTimerDisplay()));
-
 	streamingTimer->start();
 	streamingTimerDisplay->start(1000);
 	ui->outputTimerStream->setText(obs_module_text("Stop"));
 
 	UpdateStreamTimerDisplay();
+
+	ui->outputTimerStream->setChecked(true);
 }
 
 void OutputTimer::RecordTimerStart()
@@ -110,9 +115,7 @@ void OutputTimer::RecordTimerStart()
 	int minutes = ui->recordingTimerMinutes->value();
 	int seconds = ui->recordingTimerSeconds->value();
 
-	int total = (((hours * 3600) +
-			(minutes * 60)) +
-			seconds) * 1000;
+	int total = (((hours * 3600) + (minutes * 60)) + seconds) * 1000;
 
 	if (total == 0)
 		total = 1000;
@@ -120,17 +123,13 @@ void OutputTimer::RecordTimerStart()
 	recordingTimer->setInterval(total);
 	recordingTimer->setSingleShot(true);
 
-	QObject::connect(recordingTimer, SIGNAL(timeout()),
-		SLOT(EventStopRecording()));
-
-	QObject::connect(recordingTimerDisplay, SIGNAL(timeout()), this,
-		SLOT(UpdateRecordTimerDisplay()));
-
 	recordingTimer->start();
 	recordingTimerDisplay->start(1000);
 	ui->outputTimerRecord->setText(obs_module_text("Stop"));
 
 	UpdateRecordTimerDisplay();
+
+	ui->outputTimerRecord->setChecked(true);
 }
 
 void OutputTimer::StreamTimerStop()
@@ -149,6 +148,7 @@ void OutputTimer::StreamTimerStop()
 		streamingTimerDisplay->stop();
 
 	ui->streamTime->setText("00:00:00");
+	ui->outputTimerStream->setChecked(false);
 }
 
 void OutputTimer::RecordTimerStop()
@@ -167,6 +167,7 @@ void OutputTimer::RecordTimerStop()
 		recordingTimerDisplay->stop();
 
 	ui->recordTime->setText("00:00:00");
+	ui->outputTimerRecord->setChecked(false);
 }
 
 void OutputTimer::UpdateStreamTimerDisplay()
@@ -177,32 +178,58 @@ void OutputTimer::UpdateStreamTimerDisplay()
 	int minutes = (remainingTime % 3600) / 60;
 	int hours = remainingTime / 3600;
 
-	QString text;
-	text.sprintf("%02d:%02d:%02d", hours, minutes, seconds);
+	QString text =
+		QString::asprintf("%02d:%02d:%02d", hours, minutes, seconds);
 	ui->streamTime->setText(text);
 }
 
 void OutputTimer::UpdateRecordTimerDisplay()
 {
-	int remainingTime = recordingTimer->remainingTime() / 1000;
+	int remainingTime = 0;
+
+	if (obs_frontend_recording_paused() &&
+	    ui->pauseRecordTimer->isChecked())
+		remainingTime = recordingTimeLeft / 1000;
+	else
+		remainingTime = recordingTimer->remainingTime() / 1000;
 
 	int seconds = remainingTime % 60;
 	int minutes = (remainingTime % 3600) / 60;
 	int hours = remainingTime / 3600;
 
-	QString text;
-	text.sprintf("%02d:%02d:%02d", hours, minutes, seconds);
+	QString text =
+		QString::asprintf("%02d:%02d:%02d", hours, minutes, seconds);
 	ui->recordTime->setText(text);
 }
 
+void OutputTimer::PauseRecordingTimer()
+{
+	if (!ui->pauseRecordTimer->isChecked())
+		return;
+
+	if (recordingTimer->isActive()) {
+		recordingTimeLeft = recordingTimer->remainingTime();
+		recordingTimer->stop();
+	}
+}
+
+void OutputTimer::UnpauseRecordingTimer()
+{
+	if (!ui->pauseRecordTimer->isChecked())
+		return;
+
+	if (recordingTimeLeft > 0 && !recordingTimer->isActive())
+		recordingTimer->start(recordingTimeLeft);
+}
+
 void OutputTimer::ShowHideDialog()
 {
 	if (!isVisible()) {
 		setVisible(true);
-		QTimer::singleShot(250, this, SLOT(show()));
+		QTimer::singleShot(250, this, &OutputTimer::show);
 	} else {
 		setVisible(false);
-		QTimer::singleShot(250, this, SLOT(hide()));
+		QTimer::singleShot(250, this, &OutputTimer::hide);
 	}
 }
 
@@ -221,63 +248,63 @@ void OutputTimer::EventStopRecording()
 static void SaveOutputTimer(obs_data_t *save_data, bool saving, void *)
 {
 	if (saving) {
-		obs_data_t *obj = obs_data_create();
+		OBSDataAutoRelease obj = obs_data_create();
 
 		obs_data_set_int(obj, "streamTimerHours",
-				ot->ui->streamingTimerHours->value());
+				 ot->ui->streamingTimerHours->value());
 		obs_data_set_int(obj, "streamTimerMinutes",
-				ot->ui->streamingTimerMinutes->value());
+				 ot->ui->streamingTimerMinutes->value());
 		obs_data_set_int(obj, "streamTimerSeconds",
-				ot->ui->streamingTimerSeconds->value());
+				 ot->ui->streamingTimerSeconds->value());
 
 		obs_data_set_int(obj, "recordTimerHours",
-				ot->ui->recordingTimerHours->value());
+				 ot->ui->recordingTimerHours->value());
 		obs_data_set_int(obj, "recordTimerMinutes",
-				ot->ui->recordingTimerMinutes->value());
+				 ot->ui->recordingTimerMinutes->value());
 		obs_data_set_int(obj, "recordTimerSeconds",
-				ot->ui->recordingTimerSeconds->value());
+				 ot->ui->recordingTimerSeconds->value());
 
 		obs_data_set_bool(obj, "autoStartStreamTimer",
-				ot->ui->autoStartStreamTimer->isChecked());
+				  ot->ui->autoStartStreamTimer->isChecked());
 		obs_data_set_bool(obj, "autoStartRecordTimer",
-				ot->ui->autoStartRecordTimer->isChecked());
+				  ot->ui->autoStartRecordTimer->isChecked());
+
+		obs_data_set_bool(obj, "pauseRecordTimer",
+				  ot->ui->pauseRecordTimer->isChecked());
 
 		obs_data_set_obj(save_data, "output-timer", obj);
-
-		obs_data_release(obj);
 	} else {
-		obs_data_t *obj = obs_data_get_obj(save_data,
-				"output-timer");
+		OBSDataAutoRelease obj =
+			obs_data_get_obj(save_data, "output-timer");
 
 		if (!obj)
 			obj = obs_data_create();
 
 		ot->ui->streamingTimerHours->setValue(
-				obs_data_get_int(obj, "streamTimerHours"));
+			obs_data_get_int(obj, "streamTimerHours"));
 		ot->ui->streamingTimerMinutes->setValue(
-				obs_data_get_int(obj, "streamTimerMinutes"));
+			obs_data_get_int(obj, "streamTimerMinutes"));
 		ot->ui->streamingTimerSeconds->setValue(
-				obs_data_get_int(obj, "streamTimerSeconds"));
+			obs_data_get_int(obj, "streamTimerSeconds"));
 
 		ot->ui->recordingTimerHours->setValue(
-				obs_data_get_int(obj, "recordTimerHours"));
+			obs_data_get_int(obj, "recordTimerHours"));
 		ot->ui->recordingTimerMinutes->setValue(
-				obs_data_get_int(obj, "recordTimerMinutes"));
+			obs_data_get_int(obj, "recordTimerMinutes"));
 		ot->ui->recordingTimerSeconds->setValue(
-				obs_data_get_int(obj, "recordTimerSeconds"));
+			obs_data_get_int(obj, "recordTimerSeconds"));
 
 		ot->ui->autoStartStreamTimer->setChecked(
-				obs_data_get_bool(obj, "autoStartStreamTimer"));
+			obs_data_get_bool(obj, "autoStartStreamTimer"));
 		ot->ui->autoStartRecordTimer->setChecked(
-				obs_data_get_bool(obj, "autoStartRecordTimer"));
+			obs_data_get_bool(obj, "autoStartRecordTimer"));
 
-		obs_data_release(obj);
+		ot->ui->pauseRecordTimer->setChecked(
+			obs_data_get_bool(obj, "pauseRecordTimer"));
 	}
 }
 
-extern "C" void FreeOutputTimer()
-{
-}
+extern "C" void FreeOutputTimer() {}
 
 static void OBSEvent(enum obs_frontend_event event, void *)
 {
@@ -292,22 +319,25 @@ static void OBSEvent(enum obs_frontend_event event, void *)
 		ot->RecordTimerStart();
 	} else if (event == OBS_FRONTEND_EVENT_RECORDING_STOPPING) {
 		ot->RecordTimerStop();
+	} else if (event == OBS_FRONTEND_EVENT_RECORDING_PAUSED) {
+		ot->PauseRecordingTimer();
+	} else if (event == OBS_FRONTEND_EVENT_RECORDING_UNPAUSED) {
+		ot->UnpauseRecordingTimer();
 	}
 }
 
 extern "C" void InitOutputTimer()
 {
-	QAction *action = (QAction*)obs_frontend_add_tools_menu_qaction(
-			obs_module_text("OutputTimer"));
+	QAction *action = (QAction *)obs_frontend_add_tools_menu_qaction(
+		obs_module_text("OutputTimer"));
 
 	obs_frontend_push_ui_translation(obs_module_get_string);
 
-	QMainWindow *window = (QMainWindow*)obs_frontend_get_main_window();
+	QMainWindow *window = (QMainWindow *)obs_frontend_get_main_window();
 
 	ot = new OutputTimer(window);
 
-	auto cb = [] ()
-	{
+	auto cb = []() {
 		ot->ShowHideDialog();
 	};
 
