@@ -3,9 +3,10 @@
 #include <obs.hpp>
 #include <QDialog>
 #include <vector>
+#include <memory>
 
 class OBSAdvAudioCtrl;
-class QGridLayout;
+class Ui_OBSAdvAudio;
 
 // "Basic advanced audio"?  ...
 
@@ -13,12 +14,14 @@ class OBSBasicAdvAudio : public QDialog {
 	Q_OBJECT
 
 private:
-	QWidget *controlArea;
-	QGridLayout *mainLayout;
 	OBSSignal sourceAddedSignal;
 	OBSSignal sourceRemovedSignal;
+	OBSSignal sourceActivatedSignal;
+	OBSSignal sourceDeactivatedSignal;
+	bool showInactive;
+	bool showVisible;
 
-	std::vector<OBSAdvAudioCtrl*> controls;
+	std::vector<OBSAdvAudioCtrl *> controls;
 
 	inline void AddAudioSource(obs_source_t *source);
 
@@ -26,12 +29,20 @@ private:
 
 	static void OBSSourceAdded(void *param, calldata_t *calldata);
 	static void OBSSourceRemoved(void *param, calldata_t *calldata);
+	static void OBSSourceActivated(void *param, calldata_t *calldata);
+
+	std::unique_ptr<Ui_OBSAdvAudio> ui;
 
 public slots:
 	void SourceAdded(OBSSource source);
 	void SourceRemoved(OBSSource source);
 
+	void on_usePercent_toggled(bool checked);
+	void on_activeOnly_toggled(bool checked);
+
 public:
 	OBSBasicAdvAudio(QWidget *parent);
 	~OBSBasicAdvAudio();
+	void SetShowInactive(bool showInactive);
+	void SetIconsVisible(bool visible);
 };
